.. docbookrestapi

============
 V1 Web API
============

Hello
=====

.. rest-controller:: surveil.api.controllers.v1.hello:HelloController
   :webprefix: /v1/hello

Hosts
=====

.. rest-controller:: surveil.api.controllers.v1.hosts:HostsController
   :webprefix: /v1/hosts

.. rest-controller:: surveil.api.controllers.v1.hosts:HostController
   :webprefix: /v1/hosts

.. rest-controller:: surveil.api.controllers.v1.hosts:HostServicesSubController
   :webprefix: /v1/hosts/(host_name)/services

.. rest-controller:: surveil.api.controllers.v1.hosts:HostServiceSubController
   :webprefix: /v1/hosts/(host_name)/services/(service_name)

.. rest-controller:: surveil.api.controllers.v1.hosts:HostCheckResultsSubController
   :webprefix: /v1/hosts/(host_name)/results

.. rest-controller:: surveil.api.controllers.v1.hosts:ServiceCheckResultsSubController
   :webprefix: /v1/hosts/(host_name)/services/(service_description)/results

.. autotype:: surveil.api.controllers.v1.datamodel.checkresult.CheckResult
   :members:

.. autotype:: surveil.api.controllers.v1.datamodel.host.Host
   :members:

Services
========

.. rest-controller:: surveil.api.controllers.v1.services:ServicesController
   :webprefix: /v1/services

.. autotype:: surveil.api.controllers.v1.datamodel.service.Service
   :members:


Commands
========

.. rest-controller:: surveil.api.controllers.v1.commands:CommandsController
   :webprefix: /v1/commands

.. rest-controller:: surveil.api.controllers.v1.commands:CommandController
   :webprefix: /v1/commands

.. autotype:: surveil.api.controllers.v1.datamodel.command.Command
   :members:
